==> readMzXmlData_1.0.0.tar.gz: readMzXmlData/man/readMzXmlData.package.Rd <==
\encoding{utf8}
\name{readMzXmlData-package}
\alias{readMzXmlData-package}
\docType{package}
\title{The readMzXmlData Package}

\description{
The package reads mass spectrometry data in mzXML format. \cr
The package extracts only necessary functions of Jarek Tuszynski's
(\email{jaroslaw.w.tuszynski@saic.com}) \pkg{caMassClass} and \pkg{caTools}
to avoid a lot of dependencies. \cr
This follows the UNIX philosophy to provide one package which do one thing and
do it well. Also I want to try to keep it small and simple.
}
\details{
\tabular{ll}{                                                                                                                                     
Package: \tab readMzXmlData\cr                                                                                                                   
Type: \tab Package\cr                                                                                                                             
Version: \tab 1.0.0\cr                                                                                                                              
Date: \tab 2011-02-19\cr                                                                                                                          
License: \tab GPL(version 3 or later)\cr                                                                                                          
}    

Main functions:

\code{\link{readMzXmlFile}}: Reads mass spectrometry data in mzXML format.

\code{\link{readMzXmlDir}}: Reads recursively mass spectrometry data in mzXML
format in a specific directory.
}
\author{
Jarek Tuszynski (SAIC) \email{jaroslaw.w.tuszynski@saic.com} (Author of
\code{\link{read.mzXML}}), \cr
Sebastian Gibb

Maintainer: Sebastian Gibb \email{mail@sebastiangibb.de}}
\references{
See website: \url{http://www.sebastiangibb.de/maldiquant/}
}
\keyword{IO}
\seealso{
    \code{\link{readMzXmlDir}}, 
    \code{\link{readMzXmlFile}},
    \code{\link{read.mzXML}}
}

==> readMzXmlData_1.1.tar.gz: readMzXmlData/man/readMzXmlData.package.Rd <==
\encoding{utf8}
\name{readMzXmlData-package}
\alias{readMzXmlData-package}
\docType{package}
\title{The readMzXmlData Package}

\description{
The package reads mass spectrometry data in mzXML format. \cr
The package extracts only necessary functions of Jarek Tuszynski's
(\email{jaroslaw.w.tuszynski@saic.com}) \pkg{caMassClass} and \pkg{caTools}
to avoid a lot of dependencies. \cr
This follows the UNIX philosophy to provide one package which do one thing and
do it well. Also I want to try to keep it small and simple.
}
\details{
\tabular{ll}{                                                                                                                                     
Package: \tab readMzXmlData\cr                                                                                                                   
Type: \tab Package\cr                                                                                                                             
Version: \tab 1.1\cr                                                                                                                              
Date: \tab 2011-02-22\cr                                                                                                                          
License: \tab GPL(version 3 or later)\cr                                                                                                          
}    

Main functions:

\code{\link{readMzXmlFile}}: Reads mass spectrometry data in mzXML format.

\code{\link{readMzXmlDir}}: Reads recursively mass spectrometry data in mzXML
format in a specific directory.
}
\author{
Jarek Tuszynski (SAIC) \email{jaroslaw.w.tuszynski@saic.com} (Author of
\code{\link{.read.mzXML}}), \cr
Sebastian Gibb

Maintainer: Sebastian Gibb \email{mail@sebastiangibb.de}}
\references{
See website: \url{http://www.sebastiangibb.de/maldiquant/}
}
\keyword{IO}
\seealso{
    \code{\link{readMzXmlDir}}, 
    \code{\link{readMzXmlFile}},
    \code{\link{.read.mzXML}}
}
